import {
  select,
  csv,
  scaleLinear,
  max,
  scaleBand,
  axisLeft,
  axisBottom,
  scaleOrdinal
} from 'd3';

const svg = select('svg');

const width = +svg.attr('width');
const height = +svg.attr('height');
const colorScale = scaleOrdinal();


const render = data => {
  const xValue = d => d.count;
  const yValue = d => d.Primary_Type;
  const margin = { top: 20, right: 48, bottom: 48, left: 356 };
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;
  const n = colorScale.range(["#6f9f7b", "#343059", "#b42b50", "#ff9b0f"]);
  // console.log(n);
  const xScale = scaleLinear()
    .domain([0, max(data, xValue)])
    .range([0, innerWidth]);
  
  const yScale = scaleBand()
    .domain(data.map(yValue))
    .range([0, innerHeight])
    .padding(0.1);
  
  const g = svg.append('g')
    .attr('transform', `translate(${margin.left},${margin.top})`);
  
  g.append('g').call(axisLeft(yScale));
  g.append('g').call(axisBottom(xScale))
    .attr('transform', `translate(0,${innerHeight})`);
  
  g.selectAll('rect').data(data)
    .enter().append('rect')
      .attr('y', d => yScale(yValue(d)))
      .attr('width', d => xScale(xValue(d)))
      .attr('height', yScale.bandwidth())
  		.attr('fill','#cc657a');
  		// .attr('fill',function(d, i){
  		// return n(i);
  		// });
  
  g.selectAll("text")
    .data(data)
    .enter()
    .append("text")
    .text(function(d) {
        return d;
    })
    .attr("x", function(d, i) {
        return width - d - 2;
    })
    .attr("y", function(d, i) {
        return 1 * i;
    })
    .attr("fill", "#7579d1");
};

csv('data.csv').then(data => {
  data.forEach(d =>{
    d.count = +d.count;
  });
  //console.log(data);
  render(data);
});