import {
  axisLeft,
  axisBottom,
  scaleLinear,
  extent
} from 'd3'; 


export const scatterPlot = (selection, props) => {
  
    const {
    data,
    width,
    height,
    margin,
    title,
    xValue,
    xAxisLabel,
    yValue,
    yAxisLabel,
    circleRadius,
    colorValue,
    colorScale,
    selectedColorValue,
    innerWidth,
    innerHeight,
    legendLabel,
  } = props;
     

  const xScale = scaleLinear() 
    .domain(extent(data, xValue))
    .range([0, innerWidth])
    .nice();
  const yScale = scaleLinear()
    .domain(extent(data, yValue))
    .range([innerHeight, 0])
    .nice();
  const xAxis = axisBottom(xScale)
    .tickSize(-innerHeight)
    .tickPadding(5);
  const yAxis = axisLeft(yScale)
    .tickSize(-innerWidth)
    .tickPadding(10);
  
  const gUpdate = selection.selectAll('g').data([null]);  
  const gEnter = gUpdate.enter().append('g')
  const g = gUpdate.merge(gEnter);
  
  gEnter
    .attr('transform', `translate(${margin.left},${margin.top})`); 
  
  
  const yAxisG = gEnter.append('g').call(yAxis);
  yAxisG.selectAll('.domain').remove();
  
    yAxisG.append('text')
      .attr('class', 'axis-label') 
      .attr('y', -margin.left/2)
      .attr('x', -innerHeight / 2)
      .attr('fill', 'black')
      .attr('transform', `rotate(-90)`)
      .attr('text-anchor', 'middle')
      .text(yAxisLabel); 
  
  const xAxisG = gEnter.append('g').call(xAxis)
    .attr('transform', `translate(0,${innerHeight})`);
  
  xAxisG.select('.domain').remove();
  
  xAxisG
    .append('text')
      .attr('class', 'axis-label')
    .merge(xAxisG) 
      .attr('y', 75)
      .attr('x', innerWidth / 2)
      .attr('fill', 'black')
      .text(xAxisLabel);
  
  const points = g.selectAll('.datapoints')
    .data(data);
  
  const pointsEnter = points
    .enter().append('circle')
      .attr('class', 'datapoints')
      .attr('cy', d => yScale(yValue(d)))
      .attr('cx', d => xScale(xValue(d)))
      .attr('r', circleRadius+1.5)
      .attr('fill',d => colorScale(colorValue(d))); 
  
  points 
    .merge(pointsEnter) 
      .attr('opacity',d =>
         (!selectedColorValue) || (selectedColorValue == colorValue(d))
              ? 1
              : 0
        )
     .classed('highlighted', d => 
       selectedColorValue && selectedColorValue === colorValue(d))
  
}